@@ -145,7 +145,11 @@ class DataThread(threading.Thread):
 
         if full_file_path.endswith("/"):
             if not os.path.isdir(full_file_path) and not self.__dryrun:
-                os.makedirs(full_file_path)
+                try:
+                    os.makedirs(full_file_path)
+                except FileExistsError:
+                    # Directory created on another thread
+                    pass
             return (key_name, full_file_path, False)
         if os.path.exists(full_file_path):
             if not self.__overwrite_existing:
@@ -159,7 +163,11 @@ class DataThread(threading.Thread):
             os.remove(full_file_path)
         file_dir = os.path.dirname(full_file_path)
         if not os.path.isdir(file_dir) and not self.__dryrun:
-            os.makedirs(file_dir)
+            try:
+                os.makedirs(file_dir)
+            except FileExistsError:
+                # Directory created on another thread
+                pass
         if self.__dryrun:
             return (key_name, full_file_path, False)
         else:
@@ -346,6 +354,24 @@ class DataClient(Client):
                     )
                     yield file
 
+    def get_file_meta_data(self, epic_path):
+        """
+        Get the meta-data for the file at epic_path
+            :param epic_path: Path of a file in the form epic://[<folder>]/<file>
+            :type epic_path: str
+
+            :return: Dictionary of file meta-data
+            :rtype: dict
+        """
+        self._connect()
+        if epic_path.endswith("/"):
+            raise ValueError("Invalid file epic path")
+        s3_path = self._epic_path_to_s3(epic_path)
+        # bytes_buffer = io.BytesIO()
+        print(s3_path)
+        head = self._s3_client.head_object(Bucket=self._s3_bucket, Key=s3_path)
+        return head["Metadata"]
+
     def download_file(self, epic_path, destination):
         """
         Download the contents of epic_path
